@@ -1,9 +1,9 @@
 /*
  * This is the interface of the Qt Designer plugin.
  *
- * Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
  * 
- * This file is part of PyQt5.
+ * This file is part of PyQt6.
  * 
  * This file may be used under the terms of the GNU General Public License
  * version 3.0 as published by the Free Software Foundation and appearing in
@@ -25,7 +25,7 @@
 
 #include <Python.h>
 
-#include <QDesignerCustomWidgetCollectionInterface>
+#include <QtDesigner>
 #include <QList>
 #include <QObject>
 
@@ -48,8 +48,18 @@ public:
     virtual QList<QDesignerCustomWidgetInterface *> customWidgets() const;
 
 private:
+    bool importPlugins(const QString &dir, const QStringList &plugins);
     static PyObject *getModuleAttr(const char *module, const char *attr);
 
+    // The sys.path object if we need it.
+    PyObject *sys_path;
+
+    // The sip.unwrapinstance object if we need it.
+    PyObject *sip_unwrapinstance;
+
+    // The PyQt6.QtDesigner.QPyDesignerCustomWidgetPlugin object if we need it.
+    PyObject *qtdesigner_custom;
+
     QList<QDesignerCustomWidgetInterface *> widgets;
 };
 
