@@ -1,9 +1,9 @@
 // This contains definitions related to the support for Python objects and Qt's
 // meta-type system.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -40,14 +40,14 @@ public:
     ~PyQt_PyObject();
 
     PyQt_PyObject &operator=(const PyQt_PyObject &other);
+    operator QString() const;
 
     // The Python object being wrapped.
     PyObject *pyobject;
-    
-    // The Qt meta-type id.
-    static int metatype;
 };
 
+bool operator==(const PyQt_PyObject &self, const PyQt_PyObject &other);
+
 QDataStream &operator<<(QDataStream &out, const PyQt_PyObject &obj);
 QDataStream &operator>>(QDataStream &in, PyQt_PyObject &obj);
 
