@@ -1,8 +1,8 @@
 // This contains the implementation of the PyQtSlot class.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -24,54 +24,67 @@
 #include "qpycore_pyqtslot.h"
 
 
-// Create the slot for an unbound method.
-PyQtSlot::PyQtSlot(PyObject *method, PyObject *type,
-        const Chimera::Signature *slot_signature)
-    : mfunc(method), mself(0), mself_wr(0), other(0), signature(slot_signature)
-{
-#if PY_MAJOR_VERSION < 3
-    mclass = type;
-#else
-    Q_UNUSED(type)
-#endif
-}
-
-
 // Create the slot for a callable.
-PyQtSlot::PyQtSlot(PyObject *callable, const Chimera::Signature *slot_signature)
-    : mfunc(0), mself_wr(0), other(0), signature(slot_signature)
+PyQtSlot::PyQtSlot(PyObject *callable, bool callable_is_method,
+        const Chimera::Signature *slot_signature)
+    : mfunc(0), mself(0), mself_wr(0), other(0), signature(slot_signature)
 {
-    if (PyMethod_Check(callable))
+    if (callable_is_method)
     {
-        // Save the component parts.
-        mfunc = PyMethod_GET_FUNCTION(callable);
-        mself = PyMethod_GET_SELF(callable);
-#if PY_MAJOR_VERSION < 3
-        mclass = PyMethod_GET_CLASS(callable);
-#endif
-
-        // Try and create a weak reference to the instance object.
-        mself_wr = PyWeakref_NewRef(mself, 0);
+        mfunc = callable;
     }
     else
     {
-        // Give the slot an extra reference to keep it alive.
-        Py_INCREF(callable);
-        other = callable;
+        sipMethodDef callable_m;
+
+        if (sipGetMethod(callable, &callable_m))
+        {
+            // Save the component parts.
+            mfunc = callable_m.pm_function;
+            mself = callable_m.pm_self;
+
+            // Try and create a weak reference to the instance object.
+            mself_wr = PyWeakref_NewRef(mself, 0);
+        }
+        else
+        {
+            // Give the slot an extra reference to keep it alive.
+            Py_INCREF(callable);
+            other = callable;
+        }
     }
+
+    // If the slot is a method then keep the function object alive.
+    Py_XINCREF(mfunc);
 }
 
 
 // Destroy the slot.
 PyQtSlot::~PyQtSlot()
 {
+    Py_XDECREF(mfunc);
     Py_XDECREF(mself_wr);
     Py_XDECREF(other);
 }
 
 
+// Invoke the slot on behalf of C++.
+PyQtSlot::Result PyQtSlot::invoke(void **qargs, bool no_receiver_check) const
+{
+    return invoke(qargs, 0, 0, no_receiver_check);
+}
+
+
 // Invoke the slot on behalf of C++.
 bool PyQtSlot::invoke(void **qargs, PyObject *self, void *result) const
+{
+    return (invoke(qargs, self, result, false) != PyQtSlot::Failed);
+}
+
+
+// Invoke the slot on behalf of C++.
+PyQtSlot::Result PyQtSlot::invoke(void **qargs, PyObject *self, void *result,
+        bool no_receiver_check) const
 {
     // Get the callable.
     PyObject *callable;
@@ -87,15 +100,27 @@ bool PyQtSlot::invoke(void **qargs, PyObject *self, void *result) const
         if (!self)
             self = instance();
 
-        // See if the instance has gone (which isn't an error).
+        // If self is NULL then we didn't have a method in the first place.
+        // Instead we had a callable that has been cleared during garbage
+        // collection - so we can simply ignore the invocation.
         if (!self)
-            return true;
+            return PyQtSlot::Ignored;
 
-#if PY_MAJOR_VERSION < 3
-        callable = PyMethod_New(mfunc, self, mclass);
-#else
-        callable = PyMethod_New(mfunc, self);
-#endif
+        // See if the instance has gone (which isn't an error).
+        if (self == Py_None)
+            return PyQtSlot::Ignored;
+
+        // If the receiver wraps a C++ object then ignore the call if it no
+        // longer exists.
+        if (!no_receiver_check && PyObject_TypeCheck(self, sipSimpleWrapper_Type) && !sipGetAddress((sipSimpleWrapper *)self))
+            return PyQtSlot::Ignored;
+
+        sipMethodDef callable_m;
+
+        callable_m.pm_function = mfunc;
+        callable_m.pm_self = self;
+
+        callable = sipFromMethod(&callable_m);
     }
 
     // Convert the C++ arguments to Python objects.
@@ -104,7 +129,7 @@ bool PyQtSlot::invoke(void **qargs, PyObject *self, void *result) const
     PyObject *argtup = PyTuple_New(args.size());
 
     if (!argtup)
-        return false;
+        return PyQtSlot::Failed;
 
     QList<const Chimera *>::const_iterator it = args.constBegin();
 
@@ -115,22 +140,22 @@ bool PyQtSlot::invoke(void **qargs, PyObject *self, void *result) const
         if (!arg)
         {
             Py_DECREF(argtup);
-            return false;
+            return PyQtSlot::Failed;
         }
 
-        PyTuple_SET_ITEM(argtup, a, arg);
+        PyTuple_SetItem(argtup, a, arg);
 
         ++it;
     }
 
     // Dispatch to the real slot.
-    PyObject *res = invoke(callable, argtup);
+    PyObject *res = call(callable, argtup);
 
     Py_DECREF(argtup);
     Py_DECREF(callable);
 
     if (!res)
-        return false;
+        return PyQtSlot::Failed;
 
     // Handle any result if required.
     bool ok;
@@ -142,29 +167,37 @@ bool PyQtSlot::invoke(void **qargs, PyObject *self, void *result) const
 
     Py_DECREF(res);
 
-    return ok;
+    return (ok ? PyQtSlot::Succeeded : PyQtSlot::Failed);
 }
 
 
 // See if this slot corresponds to the given callable.
 bool PyQtSlot::operator==(PyObject *callable) const
 {
-    if (PyMethod_Check(callable))
+    sipMethodDef callable_m;
+
+    if (sipGetMethod(callable, &callable_m))
     {
         if (other)
             return false;
 
-        return (mfunc == PyMethod_GET_FUNCTION(callable)
-                && instance() == PyMethod_GET_SELF(callable)
-#if PY_MAJOR_VERSION < 3
-                && mclass == PyMethod_GET_CLASS(callable)
-#endif
-                );
+        return (mfunc == callable_m.pm_function && instance() == callable_m.pm_self);
     }
 
     if (!other)
         return false;
 
+    // See if it is a wrapped C++ method.  Note that the PyQt4 behaviour is to
+    // not save a reference but to save the components (as we do with methods).
+    // Hopefully it won't make a difference.  However it begs the question as
+    // to whether we should do the same with methods and rely on the garbage
+    // collector - is the current way of handling methods purely historical?
+    sipCFunctionDef other_cf, callable_cf;
+
+    if (sipGetCFunction(other, &other_cf) && sipGetCFunction(callable, &callable_cf))
+        return (other_cf.cf_self == callable_cf.cf_self &&
+                other_cf.cf_function->ml_meth == callable_cf.cf_function->ml_meth);
+
     return (other == callable);
 }
 
@@ -180,8 +213,8 @@ PyObject *PyQtSlot::instance() const
 }
 
 
-// Invoke a single slot and return the result.
-PyObject *PyQtSlot::invoke(PyObject *callable, PyObject *args) const
+// Call a single slot and return the result.
+PyObject *PyQtSlot::call(PyObject *callable, PyObject *args) const
 {
     PyObject *sa, *oxtype, *oxvalue, *oxtb;
 
@@ -199,7 +232,7 @@ PyObject *PyQtSlot::invoke(PyObject *callable, PyObject *args) const
     {
         PyObject *nsa, *xtype, *xvalue, *xtb, *res;
 
-        if ((res = PyEval_CallObject(callable, sa)) != NULL)
+        if ((res = PyObject_Call(callable, sa, NULL)) != NULL)
         {
             // Remove any previous exception.
 
@@ -223,7 +256,7 @@ PyObject *PyQtSlot::invoke(PyObject *callable, PyObject *args) const
         // with no traceback - so long as we can still reduce the number of
         // arguments and try again.
         if (!PyErr_GivenExceptionMatches(xtype, PyExc_TypeError) || xtb ||
-            PyTuple_GET_SIZE(sa) == 0)
+            PyTuple_Size(sa) == 0)
         {
             // If there is a traceback then we must have called the slot and
             // the exception was later on - so report the exception as is.
@@ -270,7 +303,7 @@ PyObject *PyQtSlot::invoke(PyObject *callable, PyObject *args) const
         }
 
         // Create the new argument tuple.
-        if ((nsa = PyTuple_GetSlice(sa, 0, PyTuple_GET_SIZE(sa) - 1)) == NULL)
+        if ((nsa = PyTuple_GetSlice(sa, 0, PyTuple_Size(sa) - 1)) == NULL)
         {
             // Tidy up.
             Py_XDECREF(oxtype);
