@@ -1,8 +1,8 @@
 // This defines the definition of the PyQtSlot class.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -34,12 +34,11 @@ public:
     {
         Succeeded,  // The invocation was successful.
         Failed,     // The invocation failed.
-        Ignored     // The invocation was ignore because the receiver has gone.
+        Ignored     // The invocation was ignored because the receiver has gone.
     };
 
-    PyQtSlot(PyObject *method, PyObject *type,
+    PyQtSlot(PyObject *callable, bool callable_is_method,
             const Chimera::Signature *slot_signature);
-    PyQtSlot(PyObject *callable, const Chimera::Signature *slot_signature);
     ~PyQtSlot();
 
     PyQtSlot::Result invoke(void **qargs, bool no_receiver_check) const;
@@ -59,9 +58,6 @@ private:
 
     PyObject *mfunc;
     PyObject *mself;
-#if PY_MAJOR_VERSION < 3
-    PyObject *mclass;
-#endif
     PyObject *mself_wr;
     PyObject *other;
 
