@@ -1,8 +1,8 @@
 // This is the support for QJsonValue.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -28,6 +28,7 @@
 // See if a Python object can be converted to a QJsonValue.
 int qpycore_canConvertTo_QJsonValue(PyObject *py)
 {
+    // Note that the API doesn't provide a test for constrained named enums.
     if (PyObject_TypeCheck(py, sipTypeAsPyTypeObject(sipType_QJsonValue_Type)))
         return 1;
 
@@ -37,11 +38,6 @@ int qpycore_canConvertTo_QJsonValue(PyObject *py)
     if (PyLong_Check(py))
         return 1;
 
-#if PY_MAJOR_VERSION < 3
-    if (PyInt_Check(py))
-        return 1;
-#endif
-
     if (PyFloat_Check(py))
         return 1;
 
@@ -52,10 +48,11 @@ int qpycore_canConvertTo_QJsonValue(PyObject *py)
     if (sipCanConvertToType(py, sipType_QJsonObject, 0))
         return 1;
 
-    if (sipCanConvertToType(py, sipType_QJsonArray, 0))
+    // We must check for QJsonValue before QJsonArray.
+    if (sipCanConvertToType(py, sipType_QJsonValue, SIP_NO_CONVERTORS))
         return 1;
 
-    return sipCanConvertToType(py, sipType_QJsonValue, SIP_NO_CONVERTORS);
+    return sipCanConvertToType(py, sipType_QJsonArray, 0);
 }
 
 
@@ -63,9 +60,24 @@ int qpycore_canConvertTo_QJsonValue(PyObject *py)
 int qpycore_convertTo_QJsonValue(PyObject *py, PyObject *transferObj,
         QJsonValue **cpp, int *isErr)
 {
+    if (py == Py_None)
+    {
+        *cpp = new QJsonValue();
+
+        return sipGetState(transferObj);
+    }
+
     if (PyObject_TypeCheck(py, sipTypeAsPyTypeObject(sipType_QJsonValue_Type)))
     {
-        *cpp = new QJsonValue((QJsonValue::Type)SIPLong_AsLong(py));
+        int v = sipConvertToEnum(py, sipType_QJsonValue_Type);
+
+        if (PyErr_Occurred())
+        {
+            *isErr = 1;
+            return 0;
+        }
+
+        *cpp = new QJsonValue(static_cast<QJsonValue::Type>(v));
 
         return sipGetState(transferObj);
     }
@@ -84,18 +96,9 @@ int qpycore_convertTo_QJsonValue(PyObject *py, PyObject *transferObj,
         return sipGetState(transferObj);
     }
 
-#if PY_MAJOR_VERSION < 3
-    if (PyInt_Check(py))
-    {
-        *cpp = new QJsonValue((int)PyInt_AS_LONG(py));
-
-        return sipGetState(transferObj);
-    }
-#endif
-
     if (PyFloat_Check(py))
     {
-        *cpp = new QJsonValue((double)PyFloat_AS_DOUBLE(py));
+        *cpp = new QJsonValue((double)PyFloat_AsDouble(py));
 
         return sipGetState(transferObj);
     }
@@ -107,10 +110,7 @@ int qpycore_convertTo_QJsonValue(PyObject *py, PyObject *transferObj,
                 sipType_QString, 0, 0, &state, isErr));
 
         if (*isErr)
-        {
-            sipReleaseType(q, sipType_QString, state);
             return 0;
-        }
 
         *cpp = new QJsonValue(*q);
 
@@ -127,10 +127,7 @@ int qpycore_convertTo_QJsonValue(PyObject *py, PyObject *transferObj,
                 sipType_QJsonObject, 0, 0, &state, isErr));
 
         if (*isErr)
-        {
-            sipReleaseType(q, sipType_QJsonObject, state);
             return 0;
-        }
 
         *cpp = new QJsonValue(*q);
 
@@ -139,17 +136,23 @@ int qpycore_convertTo_QJsonValue(PyObject *py, PyObject *transferObj,
         return sipGetState(transferObj);
     }
 
-    if (sipCanConvertToType(py, sipType_QJsonArray, 0))
+    // We must check for QJsonValue before QJsonArray.
+    if (sipCanConvertToType(py, sipType_QJsonValue, SIP_NO_CONVERTORS))
+    {
+        *cpp = reinterpret_cast<QJsonValue *>(sipConvertToType(py,
+                sipType_QJsonValue, transferObj, SIP_NO_CONVERTORS, 0, isErr));
+
+        return 0;
+    }
+
+    // Now it is safe to convert to QJsonArray.
     {
         int state;
         QJsonArray *q = reinterpret_cast<QJsonArray *>(sipConvertToType(py,
                 sipType_QJsonArray, 0, 0, &state, isErr));
 
         if (*isErr)
-        {
-            sipReleaseType(q, sipType_QJsonArray, state);
             return 0;
-        }
 
         *cpp = new QJsonValue(*q);
 
@@ -157,9 +160,4 @@ int qpycore_convertTo_QJsonValue(PyObject *py, PyObject *transferObj,
 
         return sipGetState(transferObj);
     }
-
-    *cpp = reinterpret_cast<QJsonValue *>(sipConvertToType(py, sipType_QJsonValue,
-            transferObj, SIP_NO_CONVERTORS, 0, isErr));
-
-    return 0;
 }
