@@ -1,8 +1,8 @@
 // This implements the helpers for QMetaObject.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -50,9 +50,9 @@ void qpycore_qmetaobject_connectslotsbyname(QObject *qobj,
 
     PyObject *slot_obj = 0;
 
-    for (SIP_SSIZE_T li = 0; li < PyList_GET_SIZE(dir); ++li)
+    for (Py_ssize_t li = 0; li < PyList_Size(dir); ++li)
     {
-        PyObject *name_obj = PyList_GET_ITEM(dir, li);
+        PyObject *name_obj = PyList_GetItem(dir, li);
 
         // Get the slot object.
         Py_XDECREF(slot_obj);
@@ -71,9 +71,9 @@ void qpycore_qmetaobject_connectslotsbyname(QObject *qobj,
 
         if (sigattr)
         {
-            for (SIP_SSIZE_T i = 0; i < PyList_GET_SIZE(sigattr); ++i)
+            for (Py_ssize_t i = 0; i < PyList_Size(sigattr); ++i)
             {
-                PyObject *decoration = PyList_GET_ITEM(sigattr, i);
+                PyObject *decoration = PyList_GetItem(sigattr, i);
                 Chimera::Signature *sig = Chimera::Signature::fromPyObject(decoration);
                 QByteArray args = sig->arguments();
 
@@ -85,16 +85,13 @@ void qpycore_qmetaobject_connectslotsbyname(QObject *qobj,
         }
         else
         {
-            const char *ascii_name = sipString_AsASCIIString(&name_obj);
-
-            if (!ascii_name)
+            QByteArray name = qpycore_convert_ASCII(name_obj);
+            if (name.isNull())
                 continue;
 
             PyErr_Clear();
 
-            connect(qobj, slot_obj, QByteArray(ascii_name), QByteArray());
-
-            Py_DECREF(name_obj);
+            connect(qobj, slot_obj, name, QByteArray());
         }
     }
 
@@ -150,7 +147,7 @@ static void connect(QObject *qobj, PyObject *slot_obj,
         QObject *receiver;
         QByteArray slot_sig;
 
-        if (pyqt5_get_connection_parts(slot_obj, eobj, sig.constData(), false, &receiver, slot_sig) != sipErrorNone)
+        if (pyqt6_get_connection_parts(slot_obj, eobj, sig.constData(), false, &receiver, slot_sig) != sipErrorNone)
             continue;
 
         // Add the type character.
