@@ -1,8 +1,8 @@
 // This defines the interfaces for the meta-type used by PyQt.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -22,32 +22,15 @@
 #define _QPYCORE_TYPES_H
 
 
-#include <Python.h>
-
-#include <QByteArray>
 #include <QList>
 #include <QMetaObject>
 
-#include "qpycore_chimera.h"
 #include "qpycore_pyqtproperty.h"
 
-#include "sipAPIQtCore.h"
-
 
 class PyQtSlot;
 
 
-// This describes a slot.
-struct qpycore_slot
-{
-    // The slot itself.
-    sipSlot sip_slot;
-
-    // The parsed signature.
-    const Chimera::Signature *signature;
-};
-
-
 // This describes a dynamic meta-object.
 struct qpycore_metaobject
 {
@@ -65,29 +48,9 @@ struct qpycore_metaobject
 };
 
 
-extern "C" {
-
-/*
- * The meta-type of a PyQt wrapper type.
- */
-typedef struct _pyqtWrapperType {
-    /*
-     * The super-meta-type.  This must be first in the structure so that it can
-     * be cast to a sipWrapperType *.
-     */
-    sipWrapperType super;
-
-    /*
-     * The type's dynamic metaobject (for QObject sub-classes) created by
-     * introspecting the Python type.
-     */
-    qpycore_metaobject *metaobject;
-} pyqtWrapperType;
-
-
-extern PyTypeObject qpycore_pyqtWrapperType_Type;
-
-}
+const qpycore_metaobject *qpycore_get_dynamic_metaobject(sipWrapperType *wt);
+const QMetaObject *qpycore_get_qmetaobject(sipWrapperType *wt,
+        const sipTypeDef *base_td = 0);
 
 
 #endif
