@@ -1,8 +1,8 @@
 // This defines the API provided by this library.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -31,15 +31,14 @@
 
 
 // Support for qmlRegisterType().
-int qpyqml_register_type(PyTypeObject *py_type, PyTypeObject *attached);
+int qpyqml_register_anonymous_type(PyTypeObject *py_type, const char *uri,
+        int major);
 int qpyqml_register_library_type(PyTypeObject *py_type, const char *uri,
-        int major, int minor, const char *qml_name, int revision,
-        PyTypeObject *attached);
+        int major, int minor, const char *qml_name, PyTypeObject *attached);
 int qpyqml_register_singleton_type(PyTypeObject *py_type, const char *uri,
         int major, int minor, const char *type_name, PyObject *factory);
 int qpyqml_register_uncreatable_type(PyTypeObject *py_type, const char *uri,
-        int major, int minor, const char *qml_name, const QString &reason,
-        int revision);
+        int major, int minor, const char *qml_name, const QString &reason);
 
 // Support for qmlAttachedPropertiesObject().
 QObject *qpyqml_find_proxy_for(QObject *proxied);
@@ -49,9 +48,13 @@ int qpyqml_canConvertTo_QJSValue(PyObject *py);
 int qpyqml_convertTo_QJSValue(PyObject *py, PyObject *transferObj,
         QJSValue **cpp, int *isErr);
 
-// Imports from QtCore.
-typedef const QMetaObject *(*pyqt5_qtqml_get_qmetaobject_t)(PyTypeObject *);
-extern pyqt5_qtqml_get_qmetaobject_t pyqt5_qtqml_get_qmetaobject;
+// Python exception handling.
+typedef void (*pyqt6_qtqml_err_print_t)();
+extern pyqt6_qtqml_err_print_t pyqt6_qtqml_err_print;
+
+// Other imports from QtCore.
+typedef const QMetaObject *(*pyqt6_qtqml_get_qmetaobject_t)(PyTypeObject *);
+extern pyqt6_qtqml_get_qmetaobject_t pyqt6_qtqml_get_qmetaobject;
 
 // Initialisation.
 void qpyqml_post_init(PyObject *module_dict);
