@@ -1,8 +1,8 @@
 // This is the implementation of the QPyQmlSingletonObject classes.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -61,7 +61,7 @@ QObject *QPyQmlSingletonObjectProxy::createObject(QQmlEngine *engine,
     else
     {
         qobject = 0;
-        PyErr_Print();
+        pyqt6_qtqml_err_print();
     }
 
     Py_DECREF(factory);
