@@ -1,8 +1,8 @@
 // This defines the API provided by this library.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -22,6 +22,10 @@
 #define _QPYQUICK_API_H
 
 
+// Python exception handling.
+typedef void (*pyqt6_qtquick_err_print_t)();
+extern pyqt6_qtquick_err_print_t pyqt6_qtquick_err_print;
+
 // Initialisation.
 void qpyquick_post_init();
 
