@@ -1,8 +1,8 @@
 // This is the implementation of the QPyQuickItem classes.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -28,7 +28,7 @@
 
 
 // The maximum number of Python QQuickItem types.
-const int NrOfQuickItemTypes = 30;
+const int NrOfQuickItemTypes = 60;
 
 // The list of registered Python types.
 static QList<PyTypeObject *> pyqt_types;
@@ -37,11 +37,27 @@ static QList<PyTypeObject *> pyqt_types;
 static QQmlPrivate::RegisterType canned_types[NrOfQuickItemTypes];
 
 
+// Pick the correct meta-object, either the one from the super-class or the
+// static meta-object.
+const QMetaObject *qpyquick_pick_metaobject(const QMetaObject *super_mo,
+        const QMetaObject *static_mo)
+{
+    // If a Python type has been sub-classed in QML then we need to use the
+    // QtQuick supplied meta-object.  In this case it's super-class meta-object
+    // will be the meta-object of the Python type.  Otherwise we need to use
+    // the static meta-object (which is a copy of the meta-object of the Python
+    // type).  We use the class names held by the meta-objects to determine the
+    // correct meta-object to return.
+
+    return (qstrcmp(super_mo->superClass()->className(), static_mo->className()) == 0) ? super_mo : static_mo;
+}
+
+
 #define QPYQUICKITEM_INIT(n) \
     case n##U: \
         QPyQuickItem##n::staticMetaObject = *mo; \
-        rt->typeId = qRegisterNormalizedMetaType<QPyQuickItem##n *>(ptr_name); \
-        rt->listId = qRegisterNormalizedMetaType<QQmlListProperty<QPyQuickItem##n> >(list_name); \
+        rt->typeId = QQmlPrivate::QmlMetaType<QPyQuickItem##n>::self(); \
+        rt->listId = QQmlPrivate::QmlMetaType<QPyQuickItem##n>::list(); \
         rt->objectSize = sizeof(QPyQuickItem##n); \
         rt->create = QQmlPrivate::createInto<QPyQuickItem##n>; \
         rt->metaObject = mo; \
@@ -112,6 +128,36 @@ QQmlPrivate::RegisterType *QPyQuickItem::addType(PyTypeObject *type,
         QPYQUICKITEM_INIT(27);
         QPYQUICKITEM_INIT(28);
         QPYQUICKITEM_INIT(29);
+        QPYQUICKITEM_INIT(30);
+        QPYQUICKITEM_INIT(31);
+        QPYQUICKITEM_INIT(32);
+        QPYQUICKITEM_INIT(33);
+        QPYQUICKITEM_INIT(34);
+        QPYQUICKITEM_INIT(35);
+        QPYQUICKITEM_INIT(36);
+        QPYQUICKITEM_INIT(37);
+        QPYQUICKITEM_INIT(38);
+        QPYQUICKITEM_INIT(39);
+        QPYQUICKITEM_INIT(40);
+        QPYQUICKITEM_INIT(41);
+        QPYQUICKITEM_INIT(42);
+        QPYQUICKITEM_INIT(43);
+        QPYQUICKITEM_INIT(44);
+        QPYQUICKITEM_INIT(45);
+        QPYQUICKITEM_INIT(46);
+        QPYQUICKITEM_INIT(47);
+        QPYQUICKITEM_INIT(48);
+        QPYQUICKITEM_INIT(49);
+        QPYQUICKITEM_INIT(50);
+        QPYQUICKITEM_INIT(51);
+        QPYQUICKITEM_INIT(52);
+        QPYQUICKITEM_INIT(53);
+        QPYQUICKITEM_INIT(54);
+        QPYQUICKITEM_INIT(55);
+        QPYQUICKITEM_INIT(56);
+        QPYQUICKITEM_INIT(57);
+        QPYQUICKITEM_INIT(58);
+        QPYQUICKITEM_INIT(59);
     }
 
     return rt;
@@ -128,7 +174,7 @@ void QPyQuickItem::createPyObject(QQuickItem *parent)
             NULL, &sipPySelf, "D", parent, sipType_QQuickItem, NULL);
 
     if (!obj)
-        PyErr_Print();
+        pyqt6_qtquick_err_print();
 
     SIP_UNBLOCK_THREADS
 }
@@ -140,6 +186,10 @@ QPyQuickItem##n::QPyQuickItem##n(QQuickItem *parent) : QPyQuickItem(parent) \
 { \
     createPyObject(parent); \
 } \
+const QMetaObject *QPyQuickItem##n::metaObject() const \
+{ \
+    return qpyquick_pick_metaobject(QPyQuickItem::metaObject(), &staticMetaObject); \
+} \
 QMetaObject QPyQuickItem##n::staticMetaObject
 
 
@@ -173,3 +223,33 @@ QPYQUICKITEM_IMPL(26);
 QPYQUICKITEM_IMPL(27);
 QPYQUICKITEM_IMPL(28);
 QPYQUICKITEM_IMPL(29);
+QPYQUICKITEM_IMPL(30);
+QPYQUICKITEM_IMPL(31);
+QPYQUICKITEM_IMPL(32);
+QPYQUICKITEM_IMPL(33);
+QPYQUICKITEM_IMPL(34);
+QPYQUICKITEM_IMPL(35);
+QPYQUICKITEM_IMPL(36);
+QPYQUICKITEM_IMPL(37);
+QPYQUICKITEM_IMPL(38);
+QPYQUICKITEM_IMPL(39);
+QPYQUICKITEM_IMPL(40);
+QPYQUICKITEM_IMPL(41);
+QPYQUICKITEM_IMPL(42);
+QPYQUICKITEM_IMPL(43);
+QPYQUICKITEM_IMPL(44);
+QPYQUICKITEM_IMPL(45);
+QPYQUICKITEM_IMPL(46);
+QPYQUICKITEM_IMPL(47);
+QPYQUICKITEM_IMPL(48);
+QPYQUICKITEM_IMPL(49);
+QPYQUICKITEM_IMPL(50);
+QPYQUICKITEM_IMPL(51);
+QPYQUICKITEM_IMPL(52);
+QPYQUICKITEM_IMPL(53);
+QPYQUICKITEM_IMPL(54);
+QPYQUICKITEM_IMPL(55);
+QPYQUICKITEM_IMPL(56);
+QPYQUICKITEM_IMPL(57);
+QPYQUICKITEM_IMPL(58);
+QPYQUICKITEM_IMPL(59);
